==> starthinker-1.0.10.tar.gz: starthinker-1.0.10/starthinker/task/dt/schema/Lookup.py <==
###########################################################################
#
#  Copyright 2020 Google LLC
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      https://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
#
###########################################################################

DT_Field_Lookup = {
    'Zip_Postal_Code': 'STRING',
    'Tag_Counting_Method_Id': 'INTEGER',
    'Event_Sub_Type': 'STRING',
    'Account_Id': 'INTEGER',
    'Creative_Type_Id': 'INTEGER',
    'Dbm_Total_Media_Cost_Advertiser_Currency': 'INTEGER',
    'Content_Category': 'STRING',
    'Dbm_Cpm_Fee_4_Usd': 'FLOAT',
    'Country_Code': 'STRING',
    'Rich_Media_Event_Type_Id': 'INTEGER',
    'Partitiontime': 'TIMESTAMP',
    'Partner_2_Id': 'STRING',
    'Dbm_Cpm_Fee_5_Advertiser_Currency': 'FLOAT',
    'Dbm_Media_Fee_4_Usd': 'FLOAT',
    'Billing_Invoice_Code': 'STRING',
    'Package_Roadblock_Type_Id': 'INTEGER',
    'Dbm_Browser_Platform_Id': 'INTEGER',
    'Dbm_Media_Fee_3_Partner_Currency': 'FLOAT',
    'Dbm_Revenue_Advertiser_Currency': 'FLOAT',
    'Site_Keyname': 'STRING',
    'Site_Id_Dcm': 'INTEGER',
    'Custom_Event_Timers': 'INTEGER',
    'Event_Timers': 'FLOAT',
    'Dbm_Country_Code': 'STRING',
    'Dbm_Media_Fee_5_Usd': 'FLOAT',
    'Dbm_Media_Fee_5_Partner_Currency': 'FLOAT',
    'Activity_Group': 'STRING',
    'Creative_Field_Number': 'INTEGER',
    'Floodlight_Variable_Name': 'STRING',
    'Paid_Search_Landing_Page_Url': 'STRING',
    'Dbm_Media_Fee_3_Advertiser_Currency': 'FLOAT',
    'Keyword': 'STRING',
    'Dbm_Request_Time': 'INTEGER',
    'Region': 'STRING',
    'Dma_Region': 'STRING',
    'Site_Id': 'INTEGER',
    'Placement_Cap_Cost_Option': 'STRING',
    'Dbm_Media_Fee_3_Usd': 'FLOAT',
    'Advertiser_Id': 'INTEGER',
    'Dbm_Media_Cost_Usd': 'INTEGER',
    'Creative_Version': 'STRING',
    'Creative_Size': 'STRING',
    'Creative': 'STRING',
    'Package_Roadblock_Type': 'STRING',
    'Paid_Search_Campaign': 'STRING',
    'Dbm_Total_Media_Cost_Partner_Currency': 'INTEGER',
    'Campaign': 'STRING',
    'Event_Time': 'INTEGER',
    'Dbm_Cpm_Fee_4_Advertiser_Currency': 'FLOAT',
    'Creative_Type': 'STRING',
    'Rendering_Id': 'INTEGER',
    'Dbm_Media_Fee_4_Partner_Currency': 'FLOAT',
    'Package_Roadblock_Id': 'INTEGER',
    'Content_Category_Id': 'INTEGER',
    'Referrer_Url': 'STRING',
    'Other_Data': 'STRING',
    'Dbm_Advertiser_Id': 'INTEGER',
    'Creative_Group2_Id': 'INTEGER',
    'Total_Conversions': 'INTEGER',
    'Paid_Search_Keyword': 'STRING',
    'Floodlight_Configuration': 'INTEGER',
    'Ad_Id': 'INTEGER',
    'Interaction_Time': 'STRING',
    'Flighting_Activated': 'BOOLEAN',
    'Event_Counters': 'INTEGER',
    'Region_Full_Name': 'STRING',
    'Landing_Page_Url': 'STRING',
    'Dbm_Mobile_Make_Id': 'INTEGER',
    'Active_View_Eligible_Impressions': 'INTEGER',
    'Browser_Platform_Version': 'STRING',
    'Creative_Start_Date': 'INTEGER',
    'Dbm_Cpm_Fee_3_Usd': 'FLOAT',
    'Dbm_Cpm_Fee_2_Advertiser_Currency': 'FLOAT',
    'Dbm_Revenue_Usd': 'INTEGER',
    'Advertiser_Group_Id': 'INTEGER',
    'Creative_Group1_Id': 'INTEGER',
    'Rich_Media_Event_Id': 'INTEGER',
    'Dbm_Url': 'STRING',
    'Dbm_Cpm_Fee_4_Partner_Currency': 'FLOAT',
    'Dbm_Country_Id': 'STRING',
    'Dbm_Bid_Price_Usd': 'INTEGER',
    'Campaign_End_Date': 'INTEGER',
    'Dbm_Media_Fee_1_Usd': 'FLOAT',
    'Dbm_Operating_System_Id': 'INTEGER',
    'Designated_Market_Area_Dma_Id': 'INTEGER',
    'Placement_Rate': 'INTEGER',
    'Placement': 'STRING',
    'Event_Type': 'STRING',
    'Partner_5_Id': 'STRING',
    'Ad_Type': 'STRING',
    'Segment_Value_1': 'INTEGER',
    'Total_Revenue': 'FLOAT',
    'Dbm_Media_Fee_2_Advertiser_Currency': 'FLOAT',
    'Dbm_Cpm_Fee_3_Advertiser_Currency': 'FLOAT',
    'Browser_Platform': 'STRING',
    'Dbm_Cpm_Fee_2_Usd': 'FLOAT',
    'Dbm_Data_Fees_Usd': 'FLOAT',
    'Google_Click_Id': 'STRING',
    'Dbm_Attributed_Inventory_Source_External_Id': 'STRING',
    'Dbm_Data_Fees_Partner_Currency': 'FLOAT',
    'Custom_Event_Counters': 'INTEGER',
    'Tran_Value': 'STRING',
    'U_Value': 'STRING',
    'Campaign_Start_Date': 'INTEGER',
    'Ad_Type_Id': 'INTEGER',
    'Paid_Search_Keyword_Id': 'INTEGER',
    'Dbm_Media_Cost_Partner_Currency': 'INTEGER',
    'Dbm_Media_Fee_1_Partner_Currency': 'FLOAT',
    'Dbm_Language': 'STRING',
    'Dbm_Adx_Page_Categories': 'STRING',
    'Browser_Platform_Id': 'INTEGER',
    'Floodlight_Variable_Id': 'INTEGER',
    'Dbm_Site_Id': 'INTEGER',
    'Dbm_Cpm_Fee_5_Usd': 'FLOAT',
    'Null_User_Id_Reason_Groups': 'STRING',
    'Dbm_Ad_Position': 'INTEGER',
    'Placement_Cost_Structure': 'STRING',
    'Paid_Search_Legacy_Keyword_Id': 'INTEGER',
    'Dbm_Billable_Cost_Usd': 'INTEGER',
    'Landing_Page_Url_Id': 'INTEGER',
    'Dbm_Isp_Id': 'INTEGER',
    'Paid_Search_Ad_Id': 'INTEGER',
    'Dbm_Browser_Timezone_Offset_Minutes': 'INTEGER',
    'Dbm_Bid_Price_Partner_Currency': 'INTEGER',
    'Rich_Media_Event_Type': 'STRING',
    'Activity_Group_Id': 'INTEGER',
    'Placement_Start_Date': 'INTEGER',
    'Active_View_Viewable_Impressions': 'INTEGER',
    'Dbm_Bid_Price_Advertiser_Currency': 'INTEGER',
    'Dbm_Media_Fee_2_Partner_Currency': 'FLOAT',
    'Dbm_Billable_Cost_Partner_Currency': 'INTEGER',
    'Placement_Total_Booked_Units': 'INTEGER',
    'Dbm_Total_Media_Cost_Usd': 'INTEGER',
    'Creative_Field_Value': 'STRING',
    'Dbm_Cpm_Fee_1_Advertiser_Currency': 'FLOAT',
    'Dbm_Media_Fee_5_Advertiser_Currency': 'FLOAT',
    'Creative_Field_Value_Id': 'INTEGER',
    'Dbm_Cpm_Fee_3_Partner_Currency': 'FLOAT',
    'Dma_Region_Id': 'INTEGER',
    'Partner_4_Id': 'STRING',
    'Activity_Id': 'INTEGER',
    'Paid_Search_Bid_Strategy': 'STRING',
    'City_Id': 'INTEGER',
    'Dbm_Insertion_Order_Id': 'INTEGER',
    'Placement_Id': 'INTEGER',
    'Placement_Strategy_Id': 'INTEGER',
    'Creative_Image_Url': 'STRING',
    'Dbm_Zip_Postal_Code': 'STRING',
    'Site_Directory': 'STRING',
    'Dbm_Auction_Id': 'STRING',
    'Dbm_Device_Type': 'INTEGER',
    'Conversion_Id': 'INTEGER',
    'Creative_Rotation_Type_Id': 'INTEGER',
    'Dbm_Matching_Targeted_Segments': 'STRING',
    'Ad': 'STRING',
    'Advertiser': 'STRING',
    'User_Id': 'STRING',
    'Creative_Field_Id': 'INTEGER',
    'Dbm_Revenue_Partner_Currency': 'FLOAT',
    'Dbm_Attributed_Inventory_Source_Is_Public': 'STRING',
    'Dbm_Net_Speed': 'INTEGER',
    'Site_Directory_Id': 'INTEGER',
    'Creative_End_Date': 'INTEGER',
    'Partner_1_Id': 'STRING',
    'Advertiser_Group': 'STRING',
    'City': 'STRING',
    'Paid_Search_Ad_Group': 'STRING',
    'Dbm_Media_Cost_Advertiser_Currency': 'INTEGER',
    'Dbm_Cpm_Fee_1_Partner_Currency': 'FLOAT',
    'Site': 'STRING',
    'Partner_3_Id': 'STRING',
    'Activity_Sub_Type': 'STRING',
    'Dbm_Line_Item_Id': 'INTEGER',
    'Creative_Field_Name': 'STRING',
    'Dbm_View_State': 'STRING',
    'Dbm_Mobile_Model_Id': 'INTEGER',
    'Creative_Pixel_Size': 'STRING',
    'Operating_System': 'STRING',
    'Dbm_Exchange_Id': 'STRING',
    'Operating_System_Id': 'INTEGER',
    'Dbm_Billable_Cost_Advertiser_Currency': 'INTEGER',
    'Dbm_Data_Fees_Advertiser_Currency': 'FLOAT',
    'Dbm_Cpm_Fee_5_Partner_Currency': 'FLOAT',
    'Ad_Click_Url': 'STRING',
    'Need_Description': 'STRING',
    'Placement_Strategy': 'STRING',
    'Dbm_Cpm_Fee_1_Usd': 'FLOAT',
    'Dbm_Media_Fee_1_Advertiser_Currency': 'FLOAT',
    'Rich_Media_Event_Name': 'STRING',
    'Placement_Comments': 'STRING',
    'Campaign_Id': 'INTEGER',
    'Dbm_Matching_Targeted_Keywords': 'STRING',
    'Ad_Comments': 'STRING',
    'Paid_Search_Bid_Strategy_Id': 'INTEGER',
    'Dbm_State_Region_Id': 'INTEGER',
    'Creative_Last_Modified_Date': 'INTEGER',
    'Creative_Rotation_Type': 'STRING',
    'Activity': 'STRING',
    'Ord_Value': 'STRING',
    'Paid_Search_Match_Type': 'STRING',
    'Dbm_Media_Fee_2_Usd': 'FLOAT',
    'Active_View_Measurable_Impressions': 'INTEGER',
    'Dbm_Creative_Id': 'INTEGER',
    'Impression_Id': 'STRING',
    'Dbm_Media_Fee_4_Advertiser_Currency': 'FLOAT',
    'Activity_Type': 'STRING',
    'Paid_Search_Ad_Group_Id': 'INTEGER',
    'Floodlight_Config_Id': 'INTEGER',
    'Creative_Group2': 'STRING',
    'Paid_Search_Campaign_Id': 'INTEGER',
    'Creative_Group1': 'STRING',
    'State_Region': 'STRING',
    'Placement_End_Date': 'INTEGER',
    'Dbm_Cpm_Fee_2_Partner_Currency': 'FLOAT',
    'Creative_Id': 'INTEGER',
    'Dbm_City_Id': 'INTEGER',
    'Dbm_Designated_Market_Area_Dma_Id': 'INTEGER'
}

==> starthinker-2.0.3.tar.gz: starthinker-2.0.3/starthinker/task/dt/schema/Lookup.py <==
###########################################################################
#
#  Copyright 2020 Google LLC
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      https://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
#
###########################################################################

DT_Field_Lookup = {
    'Zip_Postal_Code': 'STRING',
    'Tag_Counting_Method_Id': 'INTEGER',
    'Event_Sub_Type': 'STRING',
    'Account_Id': 'INTEGER',
    'Creative_Type_Id': 'INTEGER',
    'Dv360_Total_Media_Cost_Advertiser_Currency': 'INTEGER',
    'Content_Category': 'STRING',
    'Dv360_Cpm_Fee_4_Usd': 'FLOAT',
    'Country_Code': 'STRING',
    'Rich_Media_Event_Type_Id': 'INTEGER',
    'Partitiontime': 'TIMESTAMP',
    'Partner_2_Id': 'STRING',
    'Dv360_Cpm_Fee_5_Advertiser_Currency': 'FLOAT',
    'Dv360_Media_Fee_4_Usd': 'FLOAT',
    'Billing_Invoice_Code': 'STRING',
    'Package_Roadblock_Type_Id': 'INTEGER',
    'Dv360_Browser_Platform_Id': 'INTEGER',
    'Dv360_Media_Fee_3_Partner_Currency': 'FLOAT',
    'Dv360_Revenue_Advertiser_Currency': 'FLOAT',
    'Site_Keyname': 'STRING',
    'Site_Id_Cm360': 'INTEGER',
    'Custom_Event_Timers': 'INTEGER',
    'Event_Timers': 'FLOAT',
    'Dv360_Country_Code': 'STRING',
    'Dv360_Media_Fee_5_Usd': 'FLOAT',
    'Dv360_Media_Fee_5_Partner_Currency': 'FLOAT',
    'Activity_Group': 'STRING',
    'Creative_Field_Number': 'INTEGER',
    'Floodlight_Variable_Name': 'STRING',
    'Paid_Search_Landing_Page_Url': 'STRING',
    'Dv360_Media_Fee_3_Advertiser_Currency': 'FLOAT',
    'Keyword': 'STRING',
    'Dv360_Request_Time': 'INTEGER',
    'Region': 'STRING',
    'Dma_Region': 'STRING',
    'Site_Id': 'INTEGER',
    'Placement_Cap_Cost_Option': 'STRING',
    'Dv360_Media_Fee_3_Usd': 'FLOAT',
    'Advertiser_Id': 'INTEGER',
    'Dv360_Media_Cost_Usd': 'INTEGER',
    'Creative_Version': 'STRING',
    'Creative_Size': 'STRING',
    'Creative': 'STRING',
    'Package_Roadblock_Type': 'STRING',
    'Paid_Search_Campaign': 'STRING',
    'Dv360_Total_Media_Cost_Partner_Currency': 'INTEGER',
    'Campaign': 'STRING',
    'Event_Time': 'INTEGER',
    'Dv360_Cpm_Fee_4_Advertiser_Currency': 'FLOAT',
    'Creative_Type': 'STRING',
    'Rendering_Id': 'INTEGER',
    'Dv360_Media_Fee_4_Partner_Currency': 'FLOAT',
    'Package_Roadblock_Id': 'INTEGER',
    'Content_Category_Id': 'INTEGER',
    'Referrer_Url': 'STRING',
    'Other_Data': 'STRING',
    'Dv360_Advertiser_Id': 'INTEGER',
    'Creative_Group2_Id': 'INTEGER',
    'Total_Conversions': 'INTEGER',
    'Paid_Search_Keyword': 'STRING',
    'Floodlight_Configuration': 'INTEGER',
    'Ad_Id': 'INTEGER',
    'Interaction_Time': 'STRING',
    'Flighting_Activated': 'BOOLEAN',
    'Event_Counters': 'INTEGER',
    'Region_Full_Name': 'STRING',
    'Landing_Page_Url': 'STRING',
    'Dv360_Mobile_Make_Id': 'INTEGER',
    'Active_View_Eligible_Impressions': 'INTEGER',
    'Browser_Platform_Version': 'STRING',
    'Creative_Start_Date': 'INTEGER',
    'Dv360_Cpm_Fee_3_Usd': 'FLOAT',
    'Dv360_Cpm_Fee_2_Advertiser_Currency': 'FLOAT',
    'Dv360_Revenue_Usd': 'INTEGER',
    'Advertiser_Group_Id': 'INTEGER',
    'Creative_Group1_Id': 'INTEGER',
    'Rich_Media_Event_Id': 'INTEGER',
    'Dv360_Url': 'STRING',
    'Dv360_Cpm_Fee_4_Partner_Currency': 'FLOAT',
    'Dv360_Country_Id': 'STRING',
    'Dv360_Bid_Price_Usd': 'INTEGER',
    'Campaign_End_Date': 'INTEGER',
    'Dv360_Media_Fee_1_Usd': 'FLOAT',
    'Dv360_Operating_System_Id': 'INTEGER',
    'Designated_Market_Area_Dma_Id': 'INTEGER',
    'Placement_Rate': 'INTEGER',
    'Placement': 'STRING',
    'Event_Type': 'STRING',
    'Partner_5_Id': 'STRING',
    'Ad_Type': 'STRING',
    'Segment_Value_1': 'INTEGER',
    'Total_Revenue': 'FLOAT',
    'Dv360_Media_Fee_2_Advertiser_Currency': 'FLOAT',
    'Dv360_Cpm_Fee_3_Advertiser_Currency': 'FLOAT',
    'Browser_Platform': 'STRING',
    'Dv360_Cpm_Fee_2_Usd': 'FLOAT',
    'Dv360_Data_Fees_Usd': 'FLOAT',
    'Google_Click_Id': 'STRING',
    'Dv360_Attributed_Inventory_Source_External_Id': 'STRING',
    'Dv360_Data_Fees_Partner_Currency': 'FLOAT',
    'Custom_Event_Counters': 'INTEGER',
    'Tran_Value': 'STRING',
    'U_Value': 'STRING',
    'Campaign_Start_Date': 'INTEGER',
    'Ad_Type_Id': 'INTEGER',
    'Paid_Search_Keyword_Id': 'INTEGER',
    'Dv360_Media_Cost_Partner_Currency': 'INTEGER',
    'Dv360_Media_Fee_1_Partner_Currency': 'FLOAT',
    'Dv360_Language': 'STRING',
    'Dv360_Adx_Page_Categories': 'STRING',
    'Browser_Platform_Id': 'INTEGER',
    'Floodlight_Variable_Id': 'INTEGER',
    'Dv360_Site_Id': 'INTEGER',
    'Dv360_Cpm_Fee_5_Usd': 'FLOAT',
    'Null_User_Id_Reason_Groups': 'STRING',
    'Dv360_Ad_Position': 'INTEGER',
    'Placement_Cost_Structure': 'STRING',
    'Paid_Search_Legacy_Keyword_Id': 'INTEGER',
    'Dv360_Billable_Cost_Usd': 'INTEGER',
    'Landing_Page_Url_Id': 'INTEGER',
    'Dv360_Isp_Id': 'INTEGER',
    'Paid_Search_Ad_Id': 'INTEGER',
    'Dv360_Browser_Timezone_Offset_Minutes': 'INTEGER',
    'Dv360_Bid_Price_Partner_Currency': 'INTEGER',
    'Rich_Media_Event_Type': 'STRING',
    'Activity_Group_Id': 'INTEGER',
    'Placement_Start_Date': 'INTEGER',
    'Active_View_Viewable_Impressions': 'INTEGER',
    'Dv360_Bid_Price_Advertiser_Currency': 'INTEGER',
    'Dv360_Media_Fee_2_Partner_Currency': 'FLOAT',
    'Dv360_Billable_Cost_Partner_Currency': 'INTEGER',
    'Placement_Total_Booked_Units': 'INTEGER',
    'Dv360_Total_Media_Cost_Usd': 'INTEGER',
    'Creative_Field_Value': 'STRING',
    'Dv360_Cpm_Fee_1_Advertiser_Currency': 'FLOAT',
    'Dv360_Media_Fee_5_Advertiser_Currency': 'FLOAT',
    'Creative_Field_Value_Id': 'INTEGER',
    'Dv360_Cpm_Fee_3_Partner_Currency': 'FLOAT',
    'Dma_Region_Id': 'INTEGER',
    'Partner_4_Id': 'STRING',
    'Activity_Id': 'INTEGER',
    'Paid_Search_Bid_Strategy': 'STRING',
    'City_Id': 'INTEGER',
    'Dv360_Insertion_Order_Id': 'INTEGER',
    'Placement_Id': 'INTEGER',
    'Placement_Strategy_Id': 'INTEGER',
    'Creative_Image_Url': 'STRING',
    'Dv360_Zip_Postal_Code': 'STRING',
    'Site_Directory': 'STRING',
    'Dv360_Auction_Id': 'STRING',
    'Dv360_Device_Type': 'INTEGER',
    'Conversion_Id': 'INTEGER',
    'Creative_Rotation_Type_Id': 'INTEGER',
    'Dv360_Matching_Targeted_Segments': 'STRING',
    'Ad': 'STRING',
    'Advertiser': 'STRING',
    'User_Id': 'STRING',
    'Creative_Field_Id': 'INTEGER',
    'Dv360_Revenue_Partner_Currency': 'FLOAT',
    'Dv360_Attributed_Inventory_Source_Is_Public': 'STRING',
    'Dv360_Net_Speed': 'INTEGER',
    'Site_Directory_Id': 'INTEGER',
    'Creative_End_Date': 'INTEGER',
    'Partner_1_Id': 'STRING',
    'Advertiser_Group': 'STRING',
    'City': 'STRING',
    'Paid_Search_Ad_Group': 'STRING',
    'Dv360_Media_Cost_Advertiser_Currency': 'INTEGER',
    'Dv360_Cpm_Fee_1_Partner_Currency': 'FLOAT',
    'Site': 'STRING',
    'Partner_3_Id': 'STRING',
    'Activity_Sub_Type': 'STRING',
    'Dv360_Line_Item_Id': 'INTEGER',
    'Creative_Field_Name': 'STRING',
    'Dv360_View_State': 'STRING',
    'Dv360_Mobile_Model_Id': 'INTEGER',
    'Creative_Pixel_Size': 'STRING',
    'Operating_System': 'STRING',
    'Dv360_Exchange_Id': 'STRING',
    'Operating_System_Id': 'INTEGER',
    'Dv360_Billable_Cost_Advertiser_Currency': 'INTEGER',
    'Dv360_Data_Fees_Advertiser_Currency': 'FLOAT',
    'Dv360_Cpm_Fee_5_Partner_Currency': 'FLOAT',
    'Ad_Click_Url': 'STRING',
    'Need_Description': 'STRING',
    'Placement_Strategy': 'STRING',
    'Dv360_Cpm_Fee_1_Usd': 'FLOAT',
    'Dv360_Media_Fee_1_Advertiser_Currency': 'FLOAT',
    'Rich_Media_Event_Name': 'STRING',
    'Placement_Comments': 'STRING',
    'Campaign_Id': 'INTEGER',
    'Dv360_Matching_Targeted_Keywords': 'STRING',
    'Ad_Comments': 'STRING',
    'Paid_Search_Bid_Strategy_Id': 'INTEGER',
    'Dv360_State_Region_Id': 'INTEGER',
    'Creative_Last_Modified_Date': 'INTEGER',
    'Creative_Rotation_Type': 'STRING',
    'Activity': 'STRING',
    'Ord_Value': 'STRING',
    'Paid_Search_Match_Type': 'STRING',
    'Dv360_Media_Fee_2_Usd': 'FLOAT',
    'Active_View_Measurable_Impressions': 'INTEGER',
    'Dv360_Creative_Id': 'INTEGER',
    'Impression_Id': 'STRING',
    'Dv360_Media_Fee_4_Advertiser_Currency': 'FLOAT',
    'Activity_Type': 'STRING',
    'Paid_Search_Ad_Group_Id': 'INTEGER',
    'Floodlight_Config_Id': 'INTEGER',
    'Creative_Group2': 'STRING',
    'Paid_Search_Campaign_Id': 'INTEGER',
    'Creative_Group1': 'STRING',
    'State_Region': 'STRING',
    'Placement_End_Date': 'INTEGER',
    'Dv360_Cpm_Fee_2_Partner_Currency': 'FLOAT',
    'Creative_Id': 'INTEGER',
    'Dv360_City_Id': 'INTEGER',
    'Dv360_Designated_Market_Area_Dma_Id': 'INTEGER'
}
